@@ -175,8 +175,8 @@ static bool addArgumentsAPTHelper(std::vector<CommandLine::Args> &Args, char con
 									/*}}}*/
 static bool addArgumentsAPTGet(std::vector<CommandLine::Args> &Args, char const * const Cmd)/*{{{*/
 {
-   if (CmdMatches("install", "remove", "purge", "upgrade", "dist-upgrade",
-	    "dselect-upgrade", "autoremove", "full-upgrade"))
+   if (CmdMatches("install", "reinstall", "remove", "purge", "upgrade", "dist-upgrade",
+	    "dselect-upgrade", "autoremove", "autopurge", "full-upgrade"))
    {
       addArg(0, "show-progress", "DpkgPM::Progress", 0);
       addArg('f', "fix-broken", "APT::Get::Fix-Broken", 0);
@@ -205,7 +205,6 @@ static bool addArgumentsAPTGet(std::vector<CommandLine::Args> &Args, char const
       addArg(0, "allow-releaseinfo-change-codename", "Acquire::AllowReleaseInfoChange::Codename", 0);
       addArg(0, "allow-releaseinfo-change-suite", "Acquire::AllowReleaseInfoChange::Suite", 0);
       addArg(0, "allow-releaseinfo-change-defaultpin", "Acquire::AllowReleaseInfoChange::DefaultPin", 0);
-      addArg('e', "error-on", "APT::Update::Error-Mode", CommandLine::HasArg);
    }
    else if (CmdMatches("source"))
    {
@@ -240,8 +239,8 @@ static bool addArgumentsAPTGet(std::vector<CommandLine::Args> &Args, char const
    else if (CmdMatches("moo"))
       addArg(0, "color", "APT::Moo::Color", 0);
 
-   if (CmdMatches("install", "remove", "purge", "upgrade", "dist-upgrade",
-	    "dselect-upgrade", "autoremove", "auto-remove", "clean", "autoclean", "auto-clean", "check",
+   if (CmdMatches("install", "reinstall", "remove", "purge", "upgrade", "dist-upgrade",
+	    "dselect-upgrade", "autoremove", "auto-remove", "autopurge", "clean", "autoclean", "auto-clean", "check",
 	    "build-dep", "full-upgrade", "source"))
    {
       addArg('s', "simulate", "APT::Get::Simulate", 0);
@@ -288,11 +287,11 @@ static bool addArgumentsAPTMark(std::vector<CommandLine::Args> &Args, char const
 {
    if (CmdMatches("auto", "manual", "hold", "unhold", "showauto",
 	    "showmanual", "showhold", "showholds",
-	    "markauto", "unmarkauto"))
+	    "markauto", "unmarkauto", "minimize-manual"))
    {
       addArg('f',"file","Dir::State::extended_states",CommandLine::HasArg);
    }
-   else if (CmdMatches("install", "remove", "deinstall", "purge",
+   else if (CmdMatches("install", "reinstall", "remove", "deinstall", "purge",
 	    "showinstall", "showinstalls", "showremove", "showremoves",
 	    "showdeinstall", "showdeinstalls", "showpurge", "showpurges"))
       ;
@@ -304,7 +303,14 @@ static bool addArgumentsAPTMark(std::vector<CommandLine::Args> &Args, char const
       addArg('v',"verbose","APT::MarkAuto::Verbose",0);
    }
 
-   if (Cmd != nullptr && strncmp(Cmd, "show", strlen("show")) != 0)
+   if (CmdMatches("minimize-manual"))
+   {
+      addArg('y',"yes","APT::Get::Assume-Yes",0);
+      addArg('y',"assume-yes","APT::Get::Assume-Yes",0);
+      addArg(0,"assume-no","APT::Get::Assume-No",0);
+   }
+
+   if (CmdMatches("minimize-manual") || (Cmd != nullptr && strncmp(Cmd, "show", strlen("show")) != 0))
    {
       addArg('s',"simulate","APT::Mark::Simulate",0);
       addArg('s',"just-print","APT::Mark::Simulate",0);
