@@ -871,11 +871,7 @@ unsigned long long BaseHttpMethod::FindMaximumObjectSizeInQueue() const	/*{{{*/
 {
    unsigned long long MaxSizeInQueue = 0;
    for (FetchItem *I = Queue; I != 0 && I != QueueBack; I = I->Next)
-   {
-      if (I->MaximumSize == 0)
-	 return 0;
       MaxSizeInQueue = std::max(MaxSizeInQueue, I->MaximumSize);
-   }
    return MaxSizeInQueue;
 }
 									/*}}}*/
@@ -891,7 +887,7 @@ bool BaseHttpMethod::Configuration(std::string Message)			/*{{{*/
       return false;
 
    _config->CndSet("Acquire::tor::Proxy",
-	 "socks5h://apt-transport-tor@localhost:9050");
+	 "socks5h://apt-transport-tor@127.0.0.1:9050");
    return true;
 }
 									/*}}}*/
